@@ -97,21 +97,21 @@ static Handle cf2CF( Handle id)
 
 static struct {
    UINT format;
-   char desc[ 20];
+   char desc[ 26];
 } formats[] = {
-      {CF_METAFILEPICT     , "CF_METAFILEPICT"
-   }, {CF_SYLK             , "CF_SYLK"
-   }, {CF_DIF              , "CF_DIF"
-   }, {CF_TIFF             , "CF_TIFF"
-   }, {CF_OEMTEXT          , "CF_OEMTEXT"
-   }, {CF_PENDATA          , "CF_PENDATA"
-   }, {CF_RIFF             , "CF_RIFF"
-   }, {CF_WAVE             , "CF_WAVE"
-   }, {CF_ENHMETAFILE      , "CF_ENHMETAFILE"
-   }, {CF_HDROP            , "CF_HDROP"
-   }, {CF_LOCALE           , "CF_LOCALE"
-   }, {CF_DIBV5            , "CF_DIBV5"
-   }, {CF_MAX              , "CF_MAX"
+      {CF_METAFILEPICT     , "Win32.CF_METAFILEPICT"
+   }, {CF_SYLK             , "Win32.CF_SYLK"
+   }, {CF_DIF              , "Win32.CF_DIF"
+   }, {CF_TIFF             , "Win32.CF_TIFF"
+   }, {CF_OEMTEXT          , "Win32.CF_OEMTEXT"
+   }, {CF_PENDATA          , "Win32.CF_PENDATA"
+   }, {CF_RIFF             , "Win32.CF_RIFF"
+   }, {CF_WAVE             , "Win32.CF_WAVE"
+   }, {CF_ENHMETAFILE      , "Win32.CF_ENHMETAFILE"
+   }, {CF_HDROP            , "Win32.CF_HDROP"
+   }, {CF_LOCALE           , "Win32.CF_LOCALE"
+   }, {CF_DIBV5            , "Win32.CF_DIBV5"
+   }, {CF_MAX              , "Win32.CF_MAX"
    }
 };
 
@@ -121,19 +121,14 @@ cf2name(UINT f)
 	switch ( f ) {
 	case CF_TEXT:
 		return duplicate_string("Text");
-		break;
 	case CF_BITMAP:
 		return duplicate_string("Image");
-		break;
 	case CF_UNICODETEXT:
 		return duplicate_string("UTF8");
-		break;
 	case CF_DIB:
-		return duplicate_string("CF_DIB");
-		break;
+		return duplicate_string("Win32.CF_DIB");
 	case CF_PALETTE:
-		return duplicate_string("CF_PALETTE");
-		break;
+		return duplicate_string("Win32.CF_PALETTE");
 	default: {
 		int i = 0;
 		char name[256];
@@ -453,8 +448,9 @@ apc_clipboard_register_format( Handle self, const char * format)
 {
 	UINT r;
 	int i = 0;
+
 	while ( formats[i]. format != CF_MAX) {
-		if ( strcmp(formats[i]. desc, format) == 0) 
+		if ( strcmp(formats[i]. desc, format) == 0)
 			return formats[i]. format + cfCustom;
 		i++;
 	}
